<?php
/**
 * Google Fonts Helper.
 *
 * @package Ayyash
 * @author ThemeOO
 * @version 1.0.2
 * @since Ayyash 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

if ( ! function_exists( 'themeoo_get_all_fonts' ) ) :
	/**
	 * Returns an Array of all the Available Font Options
	 *
	 * @param bool $show_header
	 * @return array
	 */
	function themeoo_get_all_fonts( $show_header = true ) {

		if ( $show_header ) {
			return array_merge(
				[
					'------- Standard Fonts -------' => [
						'disabled' => true,
						'variants' => [],
					],
				],
				themeoo_get_standard_fonts(),
				[
					'------- Google Fonts -------' => [
						'disabled' => true,
						'variants' => [],
					],
				],
				themeoo_get_google_fonts()
			);
		}

		return array_merge(
			themeoo_get_standard_fonts(),
			themeoo_get_google_fonts()
		);
	}
endif;

if ( ! function_exists( 'themeoo_get_standard_fonts' ) ) :
	/**
	 * Returns an Array of all the Available Standard Fonts
	 *
	 * @return array
	 */
	function themeoo_get_standard_fonts() {
		return apply_filters( 'themeoo_get_standard_fonts', [
			__( 'Default', 'ayyash' ) => [
				'variants' => [
					'100',
					'100italic',
					'200',
					'300',
					'300italic',
					'regular',
					'italic',
					'500',
					'500italic',
					'700',
					'700italic',
					'900',
					'900italic',
				],
			],
			'Serif'                   => [ 'variants' => [ 'regular' ] ],
			'Sans Serif'              => [ 'variants' => [ 'regular' ] ],
			'Monospaced'              => [ 'variants' => [ 'regular' ] ],
		] );
	}
endif;

if ( ! function_exists( 'themeoo_get_google_fonts' ) ) :
	/**
	 * Returns an Array of all the Available Google Fonts
	 *
	 * @return array
	 */
	function themeoo_get_google_fonts() {
		/** @define "THEMEOO_THEME_DIR" "./../../" */
		$fonts = file_get_contents( THEMEOO_THEME_DIR . 'assets/fonts.json' );
		if ( $fonts ) {
			return json_decode( $fonts, true );
		}
		return [];
	}
endif;
