<?php
/**
 * Product quantity inputs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/quantity-input.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

/**
 * @var int|float $max_value
 * @var int|float $min_value
 * @var string $input_id
 * @var string $input_name
 * @var string[] $classes
 * @var int|float $step
 * @var int|float $input_value
 * @var string $placeholder
 * @var string $inputmode
 */
if ( $max_value && $min_value === $max_value ) { ?>
	<div class="quantity hidden">
		<input type="hidden" id="<?php echo esc_attr( $input_id ); ?>" class="qty" name="<?php echo esc_attr( $input_name ); ?>" value="<?php echo esc_attr( $min_value ); // @phpstan-ignore-line ?>" />
	</div>
	<?php
} else {
	/* translators: %s: Quantity. */
	$label = ! empty( $args['product_name'] ) ? sprintf( esc_html__( '%s quantity', 'ayyash' ), wp_strip_all_tags( $args['product_name'] ) ) : esc_html__( 'Quantity', 'ayyash' );
	?>
	<div class="quantity">
		<?php do_action( 'woocommerce_before_quantity_input_field' ); ?>
		<label class="themeoo-label" for="<?php echo esc_attr( $input_id ); ?>">
			<span class="sr-only"><?php echo esc_html( $label ); ?></span>
			<span aria-hidden="true"><?php esc_html_e( 'Qty', 'ayyash' ); ?></span>
		</label>
		<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo esc_html( $label ); ?></label>
		<input
				type="number"
				id="<?php echo esc_attr( $input_id ); ?>"
				class="<?php echo esc_attr( join( ' ', (array) $classes ) ); ?>"
				step="<?php echo esc_attr( $step ); // @phpstan-ignore-line ?>"
				min="<?php echo esc_attr( $min_value ); // @phpstan-ignore-line ?>"
				max="<?php echo esc_attr( 0 < $max_value ? $max_value : '' ); // @phpstan-ignore-line ?>"
				name="<?php echo esc_attr( $input_name ); ?>"
				value="<?php echo esc_attr( $input_value ); // @phpstan-ignore-line ?>"
				title="<?php echo esc_attr_x( 'Qty', 'Product quantity input tooltip', 'ayyash' ); ?>"
				size="4"
				placeholder="<?php echo esc_attr( $placeholder ); ?>"
				inputmode="<?php echo esc_attr( $inputmode ); ?>" />
		<?php do_action( 'woocommerce_after_quantity_input_field' ); ?>
	</div>
	<?php
}
